@@ -19,7 +19,7 @@ import inspect
 import os
 import re
 import time
-from typing import List, Type
+from typing import List, Set, Type
 import weakref
 
 from gazoo_device import config
@@ -29,6 +29,7 @@ from gazoo_device import extensions
 from gazoo_device import gdm_logger
 from gazoo_device.base_classes import auxiliary_device_base
 from gazoo_device.capabilities.interfaces import capability_base
+from gazoo_device.switchboard import log_process
 from gazoo_device.utility import common_utils
 from gazoo_device.utility import deprecation_utils
 
@@ -151,13 +152,27 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
     return [self.check_device_connected]
 
   @decorators.DynamicProperty
-  def log_file_name(self):
-    """Returns current log file name in use.
+  def log_file_name(self) -> str:
+    """Current device log file name in use.
 
     Returns:
-        str: Path to current log file name.
+      Path to current device log file name.
+
+    When the device has been recently created it might be possible that the log
+    file path does not yet exist, but will be created very soon. The caller is
+    expected to check if the file path returned exists. The caller should refer
+    to this property often because log rotation might cause the log path to
+    change depending on the max_log_size value currently in use.
     """
-    return self._log_file_name
+    current_log_filename = self._log_file_name
+
+    # Check if log file has rotated to next log filename
+    next_log_filename = log_process.get_next_log_filename(current_log_filename)
+    while os.path.exists(next_log_filename):
+      current_log_filename = next_log_filename
+      next_log_filename = log_process.get_next_log_filename(
+          current_log_filename)
+    return current_log_filename
 
   @decorators.PersistentProperty
   def regexes(self):
@@ -252,10 +267,10 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
         depends on the firmware version and is determined at runtime.
     """
     if not self.has_capabilities([capability_name]):
-      raise errors.DeviceError("{} is_capability_initialized failed. "
-                               "Capability {} is not supported by {}.".format(
-                                   self.name, capability_name,
-                                   self.device_type))
+      raise errors.DeviceError(
+          "{} get_capability_classes failed. "
+          "Capability {} is not supported by {}."
+          .format(self.name, capability_name, self.device_type))
     capability_property = getattr(type(self), capability_name)
     return list(capability_property.capability_classes)
 
@@ -340,8 +355,9 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
     return sorted(list(capability_names))
 
   @classmethod
-  def get_supported_capability_flavors(cls):
-    """Returns a set of all capability flavor classes supported by this device class."""
+  def get_supported_capability_flavors(
+      cls) -> Set[Type[capability_base.CapabilityBase]]:
+    """Returns all capability flavor classes supported by this device class."""
     capability_classes = [
         member.capability_classes
         for _, member in inspect.getmembers(cls)
@@ -525,6 +541,20 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
     """Email of the owner (maintainer) of this device class."""
     return self._OWNER_EMAIL
 
+  @decorators.LogDecorator(logger)
+  def recover(self, error: errors.CheckDeviceReadyError) -> None:
+    """Attempts to recover device based on the type of error specified.
+
+    Args:
+      error: A subclass of CheckDeviceReadyError that will be used to identify
+        a possible recovery solution to use.
+
+    Raises:
+      CheckDeviceReadyError: If there are no recovery steps available for
+        the error argument, it will be re-raised directly.
+    """
+    raise error
+
   @decorators.LogDecorator(logger, decorators.DEBUG)
   def reset_all_capabilities(self):
     """Resets all capabilities which have been initialized by deleting them.
@@ -728,7 +758,9 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
     classes.add(cls)
     property_names = []
     for a_class in classes:
+      # pytype: disable=attribute-error
       prefix = "" if a_class == cls else a_class.get_capability_name() + "."
+      # pytype: enable=attribute-error
       for name, member in inspect.getmembers(a_class):
         if isinstance(member, property_type) and not name.startswith("_"):
           property_names.append("{}{}".format(prefix, name))
@@ -748,7 +780,7 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
   def _get_switchboard_if_initialized(self):
     """Returns self.switchboard if it's initialized, None otherwise."""
     if self.is_capability_initialized("switchboard"):
-      return self.switchboard
+      return self.switchboard  # pytype: disable=attribute-error
     return None
 
   def _list_properties_dynamic_auxiliary_device(self):
